package org.eco.als.domain.bo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.eco.als.domain.Sortie;
import org.eco.common.orm.core.domain.BaseEntity;

import java.util.Date;

/**
 * 架次业务对象 als_sortie_t
 *
 * @author wgk
 * @date 2024-07-18
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = Sortie.class, reverseConvertGenerate = false)
public class SortieBo extends BaseEntity {
    /**
     * 编号
     */
    private Long id;

    /**
     * 架次号
     */
    @NotBlank(message = "架次号不能为空")
    private String sortieNo;

    /**
     * 机号
     */
    @NotNull(message = "机号不能为空")
    private String aircraftId;

    /**
     * 飞行日期
     */
    @NotNull(message = "飞行日期不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date flightDate;

    /**
     * 开始时间
     */
    @NotNull(message = "开始时间不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date startTime;

    /**
     * 结束时间
     */
    @NotBlank(message = "结束时间不能为空")
    private String endTime;

    /**
     * 飞行时长
     */
    @NotBlank(message = "飞行时长不能为空")
    private String duration;


}
