package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.AirConfigurationBo;
import org.eco.als.domain.vo.AirConfigurationImportVo;
import org.eco.als.domain.vo.AirConfigurationVo;
import org.eco.als.service.IAirConfigurationService;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;

import java.util.List;

/**
 * 飞机构型自定义导入
 *
 * @author wgk
 */
@Slf4j
public class AirConfigurationImportListener extends AnalysisEventListener<AirConfigurationImportVo> implements ExcelListener<AirConfigurationImportVo> {
    private final IAirConfigurationService airConfigurationService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public AirConfigurationImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.airConfigurationService = SpringUtils.getBean(IAirConfigurationService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(AirConfigurationImportVo airConfigurationVo, AnalysisContext context) {
        try {

            AirConfigurationBo airConfigurationBo = BeanUtil.toBean(airConfigurationVo, AirConfigurationBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            AirConfigurationVo airConfigurationVo1 = null;

            airConfigurationVo1 = airConfigurationService.selectById(airConfigurationVo.getId());
            if (ObjectUtil.isNull(airConfigurationVo1)) {
                //不存在就新增
                setBo(airConfigurationBo);
                ValidatorUtils.validate(airConfigurationBo);
                boolean inserted = airConfigurationService.insertWithPk(airConfigurationBo);//树表需要前台传来主键值

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、飞机构型 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、飞机构型 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                airConfigurationBo.setId(airConfigurationVo1.getId());//主键
                airConfigurationBo.setVersion(airConfigurationVo1.getVersion());
                boolean updated = airConfigurationService.update(airConfigurationBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、飞机构型 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、飞机构型 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、飞机构型 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(AirConfigurationBo airConfigurationBo) {
        airConfigurationBo.setVersion(0);
        if (ObjectUtil.isNull(loginUser)) {
            airConfigurationBo.setCreateBy(1L);
            airConfigurationBo.setUpdateBy(1L);
            airConfigurationBo.setTenantId(0L);
        } else {
            airConfigurationBo.setUpdateBy(loginUser.getUserId());
            airConfigurationBo.setCreateBy(loginUser.getUserId());
            airConfigurationBo.setTenantId(loginUser.getTenantId());
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<AirConfigurationImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<AirConfigurationImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
