package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.CommunicationBo;
import org.eco.als.domain.vo.CommunicationImportVo;
import org.eco.als.domain.vo.CommunicationVo;
import org.eco.als.service.ICommunicationService;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;

import java.util.List;

/**
 * 通讯管理自定义导入
 *
 * @author wgk
 */
@Slf4j
public class CommunicationImportListener extends AnalysisEventListener<CommunicationImportVo> implements ExcelListener<CommunicationImportVo> {
    private final ICommunicationService communicationService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public CommunicationImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.communicationService = SpringUtils.getBean(ICommunicationService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(CommunicationImportVo communicationVo, AnalysisContext context) {
        try {

            CommunicationBo communicationBo = BeanUtil.toBean(communicationVo, CommunicationBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            CommunicationVo communicationVo1 = null;

            //communicationVo1 = communicationService.selectBySomefield(communicationVo.getSomefield());
            if (ObjectUtil.isNull(communicationVo1)) {
                //不存在就新增
                setBo(communicationBo);
                ValidatorUtils.validate(communicationBo);
                boolean inserted = communicationService.insert(communicationBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、通讯管理 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、通讯管理 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                communicationBo.setId(communicationVo1.getId());//主键
                communicationBo.setVersion(communicationVo1.getVersion());
                boolean updated = communicationService.update(communicationBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、通讯管理 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、通讯管理 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、通讯管理 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(CommunicationBo communicationBo) {
        communicationBo.setVersion(0);
        communicationBo.setCreateBy(loginUser.getUserId());
        communicationBo.setUpdateBy(loginUser.getUserId());
        communicationBo.setTenantId(loginUser.getTenantId());
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<CommunicationImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<CommunicationImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
