package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.DataImportBo;
import org.eco.als.domain.vo.DataImportImportVo;
import org.eco.als.domain.vo.DataImportVo;
import org.eco.als.service.IDataImportService;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;

import java.util.List;

/**
 * 数据导入信息自定义导入
 *
 * @author wgk
 */
@Slf4j
public class DataImportImportListener extends AnalysisEventListener<DataImportImportVo> implements ExcelListener<DataImportImportVo> {
    private final IDataImportService dataImportService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();
    private int successNum = 0;
    private int failureNum = 0;

    public DataImportImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.dataImportService = SpringUtils.getBean(IDataImportService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(DataImportImportVo dataImportVo, AnalysisContext context) {
        try {

            DataImportBo dataImportBo = BeanUtil.toBean(dataImportVo, DataImportBo.class);
            DataImportVo dataImportVo1 = null;

            //dataImportVo1 = dataImportService.selectBySomefield(dataImportVo.getSomefield());
            if (ObjectUtil.isNull(dataImportVo1)) {
                //不存在就新增
                setBo(dataImportBo);
                ValidatorUtils.validate(dataImportBo);
                boolean inserted = dataImportService.insert(dataImportBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、数据导入信息 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、数据导入信息 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                dataImportBo.setId(dataImportVo1.getId());//主键
                dataImportBo.setVersion(dataImportVo1.getVersion());
                boolean updated = dataImportService.update(dataImportBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、数据导入信息 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、数据导入信息 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、数据导入信息 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(DataImportBo dataImportBo) {
        dataImportBo.setVersion(0);
        dataImportBo.setCreateBy(loginUser.getUserId());
        dataImportBo.setUpdateBy(loginUser.getUserId());
        dataImportBo.setTenantId(loginUser.getTenantId());
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<DataImportImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<DataImportImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
