package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import org.eco.common.core.exception.BusinessException;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.bo.FaultStatisticsBo;
import org.eco.als.domain.vo.FaultStatisticsImportVo;
import org.eco.als.domain.vo.FaultStatisticsVo;
import org.eco.als.service.IFaultStatisticsService;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 故障统计自定义导入
 *
 * @author wgk
 */
@Slf4j
public class FaultStatisticsImportListener extends AnalysisEventListener<FaultStatisticsImportVo> implements ExcelListener<FaultStatisticsImportVo> {
    private final IFaultStatisticsService faultStatisticsService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public FaultStatisticsImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.faultStatisticsService = SpringUtils.getBean(IFaultStatisticsService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(FaultStatisticsImportVo faultStatisticsVo, AnalysisContext context) {
        try {

            FaultStatisticsBo faultStatisticsBo = BeanUtil.toBean(faultStatisticsVo, FaultStatisticsBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            FaultStatisticsVo faultStatisticsVo1 = null;

            //faultStatisticsVo1 = faultStatisticsService.selectBySomefield(faultStatisticsVo.getSomefield());
            if (ObjectUtil.isNull(faultStatisticsVo1)) {
                //不存在就新增
                setBo(faultStatisticsBo);
                ValidatorUtils.validate(faultStatisticsBo);
                boolean inserted = faultStatisticsService.insert(faultStatisticsBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、故障统计 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、故障统计 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                faultStatisticsBo.setId(faultStatisticsVo1.getId());//主键
                faultStatisticsBo.setVersion(faultStatisticsVo1.getVersion());
                boolean updated = faultStatisticsService.update(faultStatisticsBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、故障统计 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、故障统计 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、故障统计 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }
    private void setBo(FaultStatisticsBo faultStatisticsBo) {
        faultStatisticsBo.setVersion(0);
        if (ObjectUtil.isNull(loginUser)) {
            faultStatisticsBo.setCreateBy(1L);
            faultStatisticsBo.setUpdateBy(1L);
            faultStatisticsBo.setTenantId(0L);
        } else {
            faultStatisticsBo.setUpdateBy(loginUser.getUserId());
            faultStatisticsBo.setCreateBy(loginUser.getUserId());
            faultStatisticsBo.setTenantId(loginUser.getTenantId());
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<FaultStatisticsImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<FaultStatisticsImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
