package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import org.eco.common.core.exception.BusinessException;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.bo.LifetimeSparePartsBo;
import org.eco.als.domain.vo.LifetimeSparePartsImportVo;
import org.eco.als.domain.vo.LifetimeSparePartsVo;
import org.eco.als.service.ILifetimeSparePartsService;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 有寿件自定义导入
 *
 * @author wgk
 */
@Slf4j
public class LifetimeSparePartsImportListener extends AnalysisEventListener<LifetimeSparePartsImportVo> implements ExcelListener<LifetimeSparePartsImportVo> {
    private final ILifetimeSparePartsService lifetimeSparePartsService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public LifetimeSparePartsImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.lifetimeSparePartsService = SpringUtils.getBean(ILifetimeSparePartsService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(LifetimeSparePartsImportVo lifetimeSparePartsVo, AnalysisContext context) {
        try {

            LifetimeSparePartsBo lifetimeSparePartsBo = BeanUtil.toBean(lifetimeSparePartsVo, LifetimeSparePartsBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            LifetimeSparePartsVo lifetimeSparePartsVo1 = null;

            //lifetimeSparePartsVo1 = lifetimeSparePartsService.selectBySomefield(lifetimeSparePartsVo.getSomefield());
            if (ObjectUtil.isNull(lifetimeSparePartsVo1)) {
                //不存在就新增
                setBo(lifetimeSparePartsBo);
                ValidatorUtils.validate(lifetimeSparePartsBo);
                boolean inserted = lifetimeSparePartsService.insert(lifetimeSparePartsBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、有寿件 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、有寿件 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                lifetimeSparePartsBo.setId(lifetimeSparePartsVo1.getId());//主键
                lifetimeSparePartsBo.setVersion(lifetimeSparePartsVo1.getVersion());
                boolean updated = lifetimeSparePartsService.update(lifetimeSparePartsBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、有寿件 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、有寿件 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、有寿件 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }
    private void setBo(LifetimeSparePartsBo lifetimeSparePartsBo) {
        lifetimeSparePartsBo.setVersion(0);
        if (ObjectUtil.isNull(loginUser)) {
            lifetimeSparePartsBo.setCreateBy(1L);
            lifetimeSparePartsBo.setUpdateBy(1L);
            lifetimeSparePartsBo.setTenantId(0L);
        } else {
            lifetimeSparePartsBo.setUpdateBy(loginUser.getUserId());
            lifetimeSparePartsBo.setCreateBy(loginUser.getUserId());
            lifetimeSparePartsBo.setTenantId(loginUser.getTenantId());
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<LifetimeSparePartsImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<LifetimeSparePartsImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
