package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.MaintenanceRecordBo;
import org.eco.als.domain.vo.MaintenanceRecordImportVo;
import org.eco.als.domain.vo.MaintenanceRecordVo;
import org.eco.als.service.IMaintenanceRecordService;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;

import java.util.List;

/**
 * 维修记录自定义导入
 *
 * @author wgk
 */
@Slf4j
public class MaintenanceRecordImportListener extends AnalysisEventListener<MaintenanceRecordImportVo> implements ExcelListener<MaintenanceRecordImportVo> {
    private final IMaintenanceRecordService maintenanceRecordService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();
    private int successNum = 0;
    private int failureNum = 0;

    public MaintenanceRecordImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.maintenanceRecordService = SpringUtils.getBean(IMaintenanceRecordService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(MaintenanceRecordImportVo maintenanceRecordVo, AnalysisContext context) {
        try {

            MaintenanceRecordBo maintenanceRecordBo = BeanUtil.toBean(maintenanceRecordVo, MaintenanceRecordBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            MaintenanceRecordVo maintenanceRecordVo1 = null;
//            maintenanceRecordVo1 = maintenanceRecordService.selectBySomefield(maintenanceRecordVo.getSomefield());
            if (ObjectUtil.isNull(maintenanceRecordVo1)) {
                //不存在就新增
                setBo(maintenanceRecordBo);
                ValidatorUtils.validate(maintenanceRecordBo);
                boolean inserted = maintenanceRecordService.insert(maintenanceRecordBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、维修记录 记录导入成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、维修记录 记录导入失败");
                    return;
                }
            } else if (isUpdateSupport) {
                //存在就更新
                maintenanceRecordBo.setId(maintenanceRecordVo1.getId());//主键
                maintenanceRecordBo.setVersion(maintenanceRecordVo1.getVersion());
                boolean updated = maintenanceRecordService.update(maintenanceRecordBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、维修记录 记录更新成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、维修记录 记录更新失败");
                    return;
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、维修记录 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(MaintenanceRecordBo maintenanceRecordBo) {
        maintenanceRecordBo.setVersion(0);
        maintenanceRecordBo.setCreateBy(loginUser.getUserId());
        maintenanceRecordBo.setUpdateBy(loginUser.getUserId());
        maintenanceRecordBo.setTenantId(loginUser.getTenantId());
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<MaintenanceRecordImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<MaintenanceRecordImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
