package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import org.eco.common.core.exception.BusinessException;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.bo.MaintenanceTaskBo;
import org.eco.als.domain.vo.MaintenanceTaskImportVo;
import org.eco.als.domain.vo.MaintenanceTaskVo;
import org.eco.als.service.IMaintenanceTaskService;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 维修信息自定义导入
 *
 * @author wgk
 */
@Slf4j
public class MaintenanceTaskImportListener extends AnalysisEventListener<MaintenanceTaskImportVo> implements ExcelListener<MaintenanceTaskImportVo> {
    private final IMaintenanceTaskService maintenanceTaskService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public MaintenanceTaskImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.maintenanceTaskService = SpringUtils.getBean(IMaintenanceTaskService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(MaintenanceTaskImportVo maintenanceTaskVo, AnalysisContext context) {
        try {

            MaintenanceTaskBo maintenanceTaskBo = BeanUtil.toBean(maintenanceTaskVo, MaintenanceTaskBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            MaintenanceTaskVo maintenanceTaskVo1 = null;

            //maintenanceTaskVo1 = maintenanceTaskService.selectBySomefield(maintenanceTaskVo.getSomefield());
            if (ObjectUtil.isNull(maintenanceTaskVo1)) {
                //不存在就新增
                setBo(maintenanceTaskBo);
                ValidatorUtils.validate(maintenanceTaskBo);
                boolean inserted = maintenanceTaskService.insert(maintenanceTaskBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、维修信息 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、维修信息 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                maintenanceTaskBo.setId(maintenanceTaskVo1.getId());//主键
                maintenanceTaskBo.setVersion(maintenanceTaskVo1.getVersion());
                boolean updated = maintenanceTaskService.update(maintenanceTaskBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、维修信息 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、维修信息 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、维修信息 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(MaintenanceTaskBo maintenanceTaskBo) {
        maintenanceTaskBo.setVersion(0);
        maintenanceTaskBo.setCreateBy(loginUser.getUserId());
        maintenanceTaskBo.setUpdateBy(loginUser.getUserId());
        maintenanceTaskBo.setTenantId(loginUser.getTenantId());
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<MaintenanceTaskImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<MaintenanceTaskImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
