package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.ModelBo;
import org.eco.als.domain.vo.ModelImportVo;
import org.eco.als.domain.vo.ModelVo;
import org.eco.als.service.IModelService;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;

import java.util.List;

/**
 * 模型信息自定义导入
 *
 * @author wgk
 */
@Slf4j
public class ModelImportListener extends AnalysisEventListener<ModelImportVo> implements ExcelListener<ModelImportVo> {
    private final IModelService modelService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();
    private int successNum = 0;
    private int failureNum = 0;

    public ModelImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.modelService = SpringUtils.getBean(IModelService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(ModelImportVo modelVo, AnalysisContext context) {
        try {

            ModelBo modelBo = BeanUtil.toBean(modelVo, ModelBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            ModelVo modelVo1 = null;

            //modelVo1 = modelService.selectBySomefield(modelVo.getSomefield());
            if (ObjectUtil.isNull(modelVo1)) {
                //不存在就新增
                setBo(modelBo);
                ValidatorUtils.validate(modelBo);
                boolean inserted = modelService.insert(modelBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、模型信息 记录导入成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、模型信息 记录导入失败");
                    return;
                }
            } else if (isUpdateSupport) {
                //存在就更新
                modelBo.setId(modelVo1.getId());//主键
                modelBo.setVersion(modelVo1.getVersion());
                boolean updated = modelService.update(modelBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、模型信息 记录更新成功");
                    return;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、模型信息 记录更新失败");
                    return;
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、模型信息 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(ModelBo modelBo) {
        modelBo.setVersion(0);
        modelBo.setCreateBy(loginUser.getUserId());
        modelBo.setUpdateBy(loginUser.getUserId());
        modelBo.setTenantId(loginUser.getTenantId());
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<ModelImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<ModelImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
