package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import org.eco.common.core.exception.BusinessException;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.bo.PersonnelAllocationBo;
import org.eco.als.domain.vo.PersonnelAllocationImportVo;
import org.eco.als.domain.vo.PersonnelAllocationVo;
import org.eco.als.service.IPersonnelAllocationService;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 维修任务任务派遣自定义导入
 *
 * @author wgk
 */
@Slf4j
public class PersonnelAllocationImportListener extends AnalysisEventListener<PersonnelAllocationImportVo> implements ExcelListener<PersonnelAllocationImportVo> {
    private final IPersonnelAllocationService personnelAllocationService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public PersonnelAllocationImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.personnelAllocationService = SpringUtils.getBean(IPersonnelAllocationService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(PersonnelAllocationImportVo personnelAllocationVo, AnalysisContext context) {
        try {

            PersonnelAllocationBo personnelAllocationBo = BeanUtil.toBean(personnelAllocationVo, PersonnelAllocationBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            PersonnelAllocationVo personnelAllocationVo1 = null;

            //personnelAllocationVo1 = personnelAllocationService.selectBySomefield(personnelAllocationVo.getSomefield());
            if (ObjectUtil.isNull(personnelAllocationVo1)) {
                //不存在就新增
                setBo(personnelAllocationBo);
                ValidatorUtils.validate(personnelAllocationBo);
                boolean inserted = personnelAllocationService.insert(personnelAllocationBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、维修任务任务派遣 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、维修任务任务派遣 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                personnelAllocationBo.setId(personnelAllocationVo1.getId());//主键
                personnelAllocationBo.setVersion(personnelAllocationVo1.getVersion());
                boolean updated = personnelAllocationService.update(personnelAllocationBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、维修任务任务派遣 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、维修任务任务派遣 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、维修任务任务派遣 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(PersonnelAllocationBo personnelAllocationBo) {
        personnelAllocationBo.setVersion(0);
        personnelAllocationBo.setCreateBy(loginUser.getUserId());
        personnelAllocationBo.setUpdateBy(loginUser.getUserId());
        personnelAllocationBo.setTenantId(loginUser.getTenantId());
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<PersonnelAllocationImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<PersonnelAllocationImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
