package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.bo.WarningBo;
import org.eco.als.domain.vo.WarningImportVo;
import org.eco.als.domain.vo.WarningVo;
import org.eco.als.service.IWarningService;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;

import java.util.List;

/**
 * 警告信息自定义导入
 *
 * @author wgk
 */
@Slf4j
public class WarningImportListener extends AnalysisEventListener<WarningImportVo> implements ExcelListener<WarningImportVo> {
    private final IWarningService warningService;

    private final Boolean isUpdateSupport;
    private final String sortieNo;
    private final LoginUser loginUser;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();
    private int successNum = 0;
    private int failureNum = 0;

    public WarningImportListener(Boolean isUpdateSupport, LoginUser loginUser, String sortieNo) {
        this.warningService = SpringUtils.getBean(IWarningService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
        this.sortieNo = sortieNo;
    }

    @Override
    public void invoke(WarningImportVo warningVo, AnalysisContext context) {
        try {

            WarningBo warningBo = BeanUtil.toBean(warningVo, WarningBo.class);
            WarningVo warningVo1 = null;
            if (ObjectUtil.isNull(warningVo1)) {
                //不存在就新增
                setBo(warningBo);
                ValidatorUtils.validate(warningBo);
                boolean inserted = warningService.insert(warningBo);
                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、警告信息 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、警告信息 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                warningBo.setId(warningVo1.getId());//主键
                warningBo.setVersion(warningVo1.getVersion());
                boolean updated = warningService.update(warningBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、警告信息 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、警告信息 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、警告信息 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(WarningBo warningBo) {
        warningBo.setVersion(0);
        warningBo.setSortieNo(sortieNo);
        if (ObjectUtil.isNull(loginUser)) {
            warningBo.setCreateBy(1L);
            warningBo.setUpdateBy(1L);
            warningBo.setTenantId(0L);
        } else {
            warningBo.setUpdateBy(loginUser.getUserId());
            warningBo.setCreateBy(loginUser.getUserId());
            warningBo.setTenantId(loginUser.getTenantId());
        }
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<WarningImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<WarningImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
