package org.eco.als.service;

import java.util.List;

import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.AirConfiguration;
import org.eco.als.domain.vo.AirConfigurationVo;
import org.eco.als.domain.bo.AirConfigurationBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

/**
 * 飞机构型Service接口
 *
 * @author wgk
 * @date 2024-11-13
 */
public interface IAirConfigurationService extends IBaseService<AirConfiguration> {
    /**
     * 查询飞机构型
     *
     * @param id 飞机构型主键
     * @return 飞机构型
     */
    AirConfigurationVo selectById(Long id);

    /**
     * 查询飞机构型
     *
     * @param name 飞机构型
     * @return 飞机构型
     */
    AirConfigurationVo selectByName(String name);

    /**
     * 查询飞机构型列表
     *
     * @param airConfigurationBo 飞机构型Bo
     * @return 飞机构型集合
     */
    List<AirConfigurationVo> selectList(AirConfigurationBo airConfigurationBo);


    /**
     * 新增飞机构型
     *
     * @param airConfigurationBo 飞机构型Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AirConfigurationBo airConfigurationBo);

    /**
     * 新增飞机构型，前台提供主键值，一般用于导入的场合
     *
     * @param airConfigurationBo 飞机构型Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(AirConfigurationBo airConfigurationBo);

    /**
     * 修改飞机构型
     *
     * @param airConfigurationBo 飞机构型Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AirConfigurationBo airConfigurationBo);

    /**
     * 批量删除飞机构型
     *
     * @param ids 需要删除的飞机构型主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<AirConfigurationVo> listVo, String sheetName, LoginUser user);

}
