package org.eco.als.service;

import org.eco.als.domain.AirInstall;
import org.eco.als.domain.bo.AirInstallBo;
import org.eco.als.domain.vo.AirInstallVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 装机信息Service接口
 *
 * @author wgk
 * @date 2024-11-21
 */
public interface IAirInstallService extends IBaseService<AirInstall> {
    /**
     * 查询装机信息
     *
     * @param id 装机信息主键
     * @return 装机信息
     */
    AirInstallVo selectById(Long id);

    /**
     * 查询装机信息列表
     *
     * @param airInstallBo 装机信息Bo
     * @return 装机信息集合
     */
    List<AirInstallVo> selectList(AirInstallBo airInstallBo);
    /**
     * 查询装机信息列表
     *
     * @param airInstallBo 装机信息Bo
     * @return 装机信息集合
     */
    List<AirInstallVo> selectListByNo(AirInstallBo airInstallBo);

    /**
     * 分页查询装机信息列表
     *
     * @param airInstallBo 装机信息Bo
     * @return 分页装机信息集合
     */
    PageResult<AirInstallVo> selectPage(AirInstallBo airInstallBo);

    /**
     * 新增装机信息
     *
     * @param airInstallBo 装机信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AirInstallBo airInstallBo);

    /**
     * 新增装机信息，前台提供主键值，一般用于导入的场合
     *
     * @param airInstallBo 装机信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(AirInstallBo airInstallBo);

    /**
     * 修改装机信息
     *
     * @param airInstallBo 装机信息Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AirInstallBo airInstallBo);

    /**
     * 批量删除装机信息
     *
     * @param ids 需要删除的装机信息主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<AirInstallVo> listVo, String sheetName, LoginUser user);

}
