package org.eco.als.service;

import org.eco.als.domain.AtlasFile;
import org.eco.als.domain.bo.AtlasFileBo;
import org.eco.als.domain.vo.AtlasFileVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 文件管理Service接口
 *
 * @author wgk
 * @date 2024-11-27
 */
public interface IAtlasFileService extends IBaseService<AtlasFile> {
    /**
     * 查询文件管理
     *
     * @param id 文件管理主键
     * @return 文件管理
     */
    AtlasFileVo selectById(Long id);

    /**
     * 查询文件管理列表
     *
     * @param atlasFileBo 文件管理Bo
     * @return 文件管理集合
     */
    List<AtlasFileVo> selectList(AtlasFileBo atlasFileBo);

    /**
     * 分页查询文件管理列表
     *
     * @param atlasFileBo 文件管理Bo
     * @return 分页文件管理集合
     */
    PageResult<AtlasFileVo> selectPage(AtlasFileBo atlasFileBo);

    /**
     * 新增文件管理
     *
     * @param atlasFileBo 文件管理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(AtlasFileBo atlasFileBo);

    /**
     * 新增文件管理，前台提供主键值，一般用于导入的场合
     *
     * @param atlasFileBo 文件管理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(AtlasFileBo atlasFileBo);

    /**
     * 修改文件管理
     *
     * @param atlasFileBo 文件管理Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(AtlasFileBo atlasFileBo);

    /**
     * 批量删除文件管理
     *
     * @param ids 需要删除的文件管理主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<AtlasFileVo> listVo, String sheetName, LoginUser user);

}
