package org.eco.als.service;

import org.eco.als.domain.Communication;
import org.eco.als.domain.bo.CommunicationBo;
import org.eco.als.domain.vo.CommunicationVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 通讯管理Service接口
 *
 * @author wgk
 * @date 2024-12-17
 */
public interface ICommunicationService extends IBaseService<Communication> {
    /**
     * 查询通讯管理
     *
     * @param id 通讯管理主键
     * @return 通讯管理
     */
    CommunicationVo selectById(Long id);

    /**
     * 查询通讯管理列表
     *
     * @param communicationBo 通讯管理Bo
     * @return 通讯管理集合
     */
    List<CommunicationVo> selectList(CommunicationBo communicationBo);

    /**
     * 分页查询通讯管理列表
     *
     * @param communicationBo 通讯管理Bo
     * @return 分页通讯管理集合
     */
    PageResult<CommunicationVo> selectPage(CommunicationBo communicationBo);

    /**
     * 新增通讯管理
     *
     * @param communicationBo 通讯管理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(CommunicationBo communicationBo);

    /**
     * 新增通讯管理，前台提供主键值，一般用于导入的场合
     *
     * @param communicationBo 通讯管理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(CommunicationBo communicationBo);

    /**
     * 修改通讯管理
     *
     * @param communicationBo 通讯管理Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(CommunicationBo communicationBo);

    /**
     * 批量删除通讯管理
     *
     * @param ids 需要删除的通讯管理主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<CommunicationVo> listVo, String sheetName, LoginUser user);

}
