package org.eco.als.service;

import org.eco.als.domain.Contacts;
import org.eco.als.domain.bo.ContactsBo;
import org.eco.als.domain.vo.ContactsVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 通讯录Service接口
 *
 * @author wgk
 * @date 2024-11-25
 */
public interface IContactsService extends IBaseService<Contacts> {
    /**
     * 查询通讯录
     *
     * @param id 通讯录主键
     * @return 通讯录
     */
    ContactsVo selectById(Long id);

    /**
     * 查询通讯录列表
     *
     * @param contactsBo 通讯录Bo
     * @return 通讯录集合
     */
    List<ContactsVo> selectList(ContactsBo contactsBo);

    /**
     * 分页查询通讯录列表
     *
     * @param contactsBo 通讯录Bo
     * @return 分页通讯录集合
     */
    PageResult<ContactsVo> selectPage(ContactsBo contactsBo);

    /**
     * 新增通讯录
     *
     * @param contactsBo 通讯录Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(ContactsBo contactsBo);

    /**
     * 新增通讯录，前台提供主键值，一般用于导入的场合
     *
     * @param contactsBo 通讯录Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(ContactsBo contactsBo);

    /**
     * 修改通讯录
     *
     * @param contactsBo 通讯录Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(ContactsBo contactsBo);

    /**
     * 批量删除通讯录
     *
     * @param ids 需要删除的通讯录主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<ContactsVo> listVo, String sheetName, LoginUser user);

}
