package org.eco.als.service;

import org.eco.als.domain.DataImport;
import org.eco.als.domain.bo.DataImportBo;
import org.eco.als.domain.vo.DataImportVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 数据导入信息Service接口
 *
 * @author wgk
 * @date 2024-07-22
 */
public interface IDataImportService extends IBaseService<DataImport> {
    /**
     * 查询数据导入信息
     *
     * @param id 数据导入信息主键
     * @return 数据导入信息
     */
    DataImportVo selectById(Long id);

    /**
     * 查询数据导入信息
     *
     * @param sortieNo 架次号
     * @return 数据导入信息
     */
    DataImportVo selectBySortieNo(String sortieNo);

    /**
     * 查询数据导入信息列表
     *
     * @param dataImportBo 数据导入信息Bo
     * @return 数据导入信息集合
     */
    List<DataImportVo> selectList(DataImportBo dataImportBo);

    /**
     * 分页查询数据导入信息列表
     *
     * @param dataImportBo 数据导入信息Bo
     * @return 分页数据导入信息集合
     */
    PageResult<DataImportVo> selectPage(DataImportBo dataImportBo);

    /**
     * 新增数据导入信息
     *
     * @param dataImportBo 数据导入信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(DataImportBo dataImportBo);

    /**
     * 新增数据导入信息，前台提供主键值，一般用于导入的场合
     *
     * @param dataImportBo 数据导入信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(DataImportBo dataImportBo);

    /**
     * 修改数据导入信息
     *
     * @param dataImportBo 数据导入信息Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(DataImportBo dataImportBo);

    /**
     * 批量删除数据导入信息
     *
     * @param ids 需要删除的数据导入信息主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<DataImportVo> listVo, String sheetName, LoginUser user);

}
