package org.eco.als.service;

import org.eco.als.domain.FalseAlarmResult;
import org.eco.als.domain.bo.FalseAlarmResultBo;
import org.eco.als.domain.vo.FalseAlarmResultVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;

import java.util.List;

/**
 * 虚警抑制结果Service接口
 *
 * @author wgk
 * @date 2024-07-23
 */
public interface IFalseAlarmResultService extends IBaseService<FalseAlarmResult> {
    /**
     * 查询虚警抑制结果
     *
     * @param id 虚警抑制结果主键
     * @return 虚警抑制结果
     */
    FalseAlarmResultVo selectById(Long id);

    /**
     * 查询虚警抑制结果列表
     *
     * @param falseAlarmResultBo 虚警抑制结果Bo
     * @return 虚警抑制结果集合
     */
    List<FalseAlarmResultVo> selectList(FalseAlarmResultBo falseAlarmResultBo);

    /**
     * 分页查询虚警抑制结果列表
     *
     * @param falseAlarmResultBo 虚警抑制结果Bo
     * @return 分页虚警抑制结果集合
     */
    PageResult<FalseAlarmResultVo> selectPage(FalseAlarmResultBo falseAlarmResultBo);

    /**
     * 新增虚警抑制结果
     *
     * @param falseAlarmResultBo 虚警抑制结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FalseAlarmResultBo falseAlarmResultBo);

    /**
     * 新增虚警抑制结果，前台提供主键值，一般用于导入的场合
     *
     * @param falseAlarmResultBo 虚警抑制结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FalseAlarmResultBo falseAlarmResultBo);

    /**
     * 修改虚警抑制结果
     *
     * @param falseAlarmResultBo 虚警抑制结果Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FalseAlarmResultBo falseAlarmResultBo);

    /**
     * 批量删除虚警抑制结果
     *
     * @param ids 需要删除的虚警抑制结果主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FalseAlarmResultVo> listVo, String sheetName, LoginUser user);

}
