package org.eco.als.service;

import org.eco.als.domain.FalseAlarm;
import org.eco.als.domain.bo.FalseAlarmBo;
import org.eco.als.domain.vo.FalseAlarmVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;

import java.util.List;

/**
 * 虚警抑制Service接口
 *
 * @author wgk
 * @date 2024-07-23
 */
public interface IFalseAlarmService extends IBaseService<FalseAlarm> {
    /**
     * 查询虚警抑制
     *
     * @param id 虚警抑制主键
     * @return 虚警抑制
     */
    FalseAlarmVo selectById(Long id);

    /**
     * 查询虚警抑制列表
     *
     * @param falseAlarmBo 虚警抑制Bo
     * @return 虚警抑制集合
     */
    List<FalseAlarmVo> selectList(FalseAlarmBo falseAlarmBo);

    /**
     * 分页查询虚警抑制列表
     *
     * @param falseAlarmBo 虚警抑制Bo
     * @return 分页虚警抑制集合
     */
    PageResult<FalseAlarmVo> selectPage(FalseAlarmBo falseAlarmBo);

    /**
     * 新增虚警抑制
     *
     * @param falseAlarmBo 虚警抑制Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    FalseAlarm insert(FalseAlarmBo falseAlarmBo);

    /**
     * 新增虚警抑制，前台提供主键值，一般用于导入的场合
     *
     * @param falseAlarmBo 虚警抑制Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FalseAlarmBo falseAlarmBo);

    /**
     * 修改虚警抑制
     *
     * @param falseAlarmBo 虚警抑制Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FalseAlarmBo falseAlarmBo);

    /**
     * 批量删除虚警抑制
     *
     * @param ids 需要删除的虚警抑制主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FalseAlarmVo> listVo, String sheetName, LoginUser user);

}
