package org.eco.als.service;

import java.util.List;

import org.dromara.easyes.core.biz.EsPageInfo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.FaultCase;
import org.eco.als.domain.vo.FaultCaseVo;
import org.eco.als.domain.bo.FaultCaseBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 故障案例Service接口
 *
 * @author wgk
 * @date 2024-12-13
 */
public interface IFaultCaseService extends IBaseService<FaultCase> {
    /**
     * 查询故障案例
     *
     * @param id 故障案例主键
     * @return 故障案例
     */
        FaultCaseVo selectById(Long id);
    /**
     * 查询故障案例列表
     *
     * @param faultCaseBo 故障案例Bo
     * @return 故障案例集合
     */
    List<FaultCaseVo> selectList(FaultCaseBo faultCaseBo);

    /**
     * 分页查询故障案例列表
     *
     * @param faultCaseBo 故障案例Bo
     * @return 分页故障案例集合
     */
    PageResult<FaultCaseVo> selectPage(FaultCaseBo faultCaseBo);
    EsPageInfo<FaultCase> selectEsPage(FaultCaseBo faultCaseBo);

    /**
     * 新增故障案例
     *
     * @param faultCaseBo 故障案例Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FaultCaseBo faultCaseBo);

    /**
     * 新增故障案例，前台提供主键值，一般用于导入的场合
     *
     * @param faultCaseBo 故障案例Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FaultCaseBo faultCaseBo);

    /**
     * 修改故障案例
     *
     * @param faultCaseBo 故障案例Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FaultCaseBo faultCaseBo);

    /**
     * 批量删除故障案例
     *
     * @param ids 需要删除的故障案例主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);
}
