package org.eco.als.service;

import org.eco.als.domain.FaultDiagnosisResult;
import org.eco.als.domain.bo.FaultDiagnosisResultBo;
import org.eco.als.domain.vo.FaultDiagnosisResultVo;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;

import java.util.List;

/**
 * 故障诊断结果Service接口
 *
 * @author wgk
 * @date 2024-11-25
 */
public interface IFaultDiagnosisResultService extends IBaseService<FaultDiagnosisResult> {
    /**
     * 查询故障诊断结果
     *
     * @param id 故障诊断结果主键
     * @return 故障诊断结果
     */
    FaultDiagnosisResultVo selectById(Long id);

    /**
     * 查询故障诊断结果列表
     *
     * @param faultDiagnosisResultBo 故障诊断结果Bo
     * @return 故障诊断结果集合
     */
    List<FaultDiagnosisResultVo> selectList(FaultDiagnosisResultBo faultDiagnosisResultBo);

    /**
     * 分页查询故障诊断结果列表
     *
     * @param faultDiagnosisResultBo 故障诊断结果Bo
     * @return 分页故障诊断结果集合
     */
    PageResult<FaultDiagnosisResultVo> selectPage(FaultDiagnosisResultBo faultDiagnosisResultBo);

    /**
     * 新增故障诊断结果
     *
     * @param faultDiagnosisResultBo 故障诊断结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FaultDiagnosisResultBo faultDiagnosisResultBo);

    /**
     * 新增故障诊断结果，前台提供主键值，一般用于导入的场合
     *
     * @param faultDiagnosisResultBo 故障诊断结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FaultDiagnosisResultBo faultDiagnosisResultBo);

    /**
     * 修改故障诊断结果
     *
     * @param faultDiagnosisResultBo 故障诊断结果Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FaultDiagnosisResultBo faultDiagnosisResultBo);

    /**
     * 批量删除故障诊断结果
     *
     * @param ids 需要删除的故障诊断结果主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);
}
