package org.eco.als.service;

import org.eco.als.domain.FaultDiagnosis;
import org.eco.als.domain.bo.FaultDiagnosisBo;
import org.eco.als.domain.vo.FaultDiagnosisVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;

import java.util.List;

/**
 * 故障诊断Service接口
 *
 * @author wgk
 * @date 2024-07-23
 */
public interface IFaultDiagnosisService extends IBaseService<FaultDiagnosis> {
    /**
     * 查询故障诊断
     *
     * @param id 故障诊断主键
     * @return 故障诊断
     */
    FaultDiagnosisVo selectById(Long id);

    /**
     * 查询故障诊断列表
     *
     * @param faultDiagnosisBo 故障诊断Bo
     * @return 故障诊断集合
     */
    List<FaultDiagnosisVo> selectList(FaultDiagnosisBo faultDiagnosisBo);

    /**
     * 分页查询故障诊断列表
     *
     * @param faultDiagnosisBo 故障诊断Bo
     * @return 分页故障诊断集合
     */
    PageResult<FaultDiagnosisVo> selectPage(FaultDiagnosisBo faultDiagnosisBo);

    /**
     * 新增故障诊断
     *
     * @param faultDiagnosisBo 故障诊断Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    FaultDiagnosis insert(FaultDiagnosisBo faultDiagnosisBo);

    /**
     * 新增故障诊断，前台提供主键值，一般用于导入的场合
     *
     * @param faultDiagnosisBo 故障诊断Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FaultDiagnosisBo faultDiagnosisBo);

    /**
     * 修改故障诊断
     *
     * @param faultDiagnosisBo 故障诊断Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FaultDiagnosisBo faultDiagnosisBo);

    /**
     * 批量删除故障诊断
     *
     * @param ids 需要删除的故障诊断主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FaultDiagnosisVo> listVo, String sheetName, LoginUser user);

}
