package org.eco.als.service;

import org.eco.als.domain.KGraphClause;
import org.eco.als.domain.bo.KGraphClauseBo;
import org.eco.als.domain.vo.KGraphClauseVo;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;

import java.util.List;

/**
 * 知识图谱分句结果Service接口
 *
 * @author wgk
 * @date 2025-01-03
 */
public interface IKGraphClauseService extends IBaseService<KGraphClause> {
    /**
     * 查询知识图谱分句结果
     *
     * @param id 知识图谱分句结果主键
     * @return 知识图谱分句结果
     */
    KGraphClauseVo selectById(Long id);

    /**
     * 查询知识图谱分句结果列表
     *
     * @param kGraphClauseBo 知识图谱分句结果Bo
     * @return 知识图谱分句结果集合
     */
    List<KGraphClauseVo> selectList(KGraphClauseBo kGraphClauseBo);

    /**
     * 分页查询知识图谱分句结果列表
     *
     * @param kGraphClauseBo 知识图谱分句结果Bo
     * @return 分页知识图谱分句结果集合
     */
    PageResult<KGraphClauseVo> selectPage(KGraphClauseBo kGraphClauseBo);

    /**
     * 新增知识图谱分句结果
     *
     * @param kGraphClauseBo 知识图谱分句结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(KGraphClauseBo kGraphClauseBo);

    /**
     * 新增知识图谱分句结果
     *
     * @param kGraphClauseBoLists 知识图谱分句结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean saveBatch(List<KGraphClauseBo> kGraphClauseBoLists);

    /**
     * 新增知识图谱分句结果，前台提供主键值，一般用于导入的场合
     *
     * @param kGraphClauseBo 知识图谱分句结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(KGraphClauseBo kGraphClauseBo);

    /**
     * 修改知识图谱分句结果
     *
     * @param kGraphClauseBo 知识图谱分句结果Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(KGraphClauseBo kGraphClauseBo);

    /**
     * 批量删除知识图谱分句结果
     *
     * @param ids 需要删除的知识图谱分句结果主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

}
