package org.eco.als.service;

import org.eco.als.domain.KGraphEntity;
import org.eco.als.domain.bo.KGraphEntityBo;
import org.eco.als.domain.vo.KGraphEntityVo;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;

import java.util.List;

/**
 * 知识图谱实体关系Service接口
 *
 * @author wgk
 * @date 2025-01-03
 */
public interface IKGraphEntityService extends IBaseService<KGraphEntity> {
    /**
     * 查询知识图谱实体关系
     *
     * @param id 知识图谱实体关系主键
     * @return 知识图谱实体关系
     */
    KGraphEntityVo selectById(Long id);

    /**
     * 查询知识图谱实体关系列表
     *
     * @param kGraphEntityBo 知识图谱实体关系Bo
     * @return 知识图谱实体关系集合
     */
    List<KGraphEntityVo> selectList(KGraphEntityBo kGraphEntityBo);

    /**
     * 查询知识图谱实体关系列表
     *
     * @param taskId TaskId
     * @return 知识图谱实体关系集合
     */
    List<KGraphEntityVo> selectListByTaskId(Long taskId);

    /**
     * 分页查询知识图谱实体关系列表
     *
     * @param kGraphEntityBo 知识图谱实体关系Bo
     * @return 分页知识图谱实体关系集合
     */
    PageResult<KGraphEntityVo> selectPage(KGraphEntityBo kGraphEntityBo);

    /**
     * 新增知识图谱实体关系
     *
     * @param kGraphEntityBo 知识图谱实体关系Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(KGraphEntityBo kGraphEntityBo);

    /**
     * 新增知识图谱实体关系
     *
     * @param kGraphEntityBoList 知识图谱实体关系Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean saveBatch(List<KGraphEntityBo> kGraphEntityBoList);

    /**
     * 新增知识图谱实体关系，前台提供主键值，一般用于导入的场合
     *
     * @param kGraphEntityBo 知识图谱实体关系Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(KGraphEntityBo kGraphEntityBo);

    /**
     * 修改知识图谱实体关系
     *
     * @param kGraphEntityBo 知识图谱实体关系Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(KGraphEntityBo kGraphEntityBo);

    /**
     * 批量删除知识图谱实体关系
     *
     * @param ids 需要删除的知识图谱实体关系主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);
}
