package org.eco.als.service;

import org.eco.als.domain.KGraphTask;
import org.eco.als.domain.bo.ExtraKGraphTaskBo;
import org.eco.als.domain.bo.ExtraKGraphTaskStatusBo;
import org.eco.als.domain.bo.KGraphTaskBo;
import org.eco.als.domain.vo.KGraphTaskVo;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;

import java.util.List;

/**
 * 知识图谱任务Service接口
 *
 * @author wgk
 * @date 2025-01-03
 */
public interface IKGraphTaskService extends IBaseService<KGraphTask> {
    /**
     * 查询知识图谱任务
     *
     * @param id 知识图谱任务主键
     * @return 知识图谱任务
     */
    KGraphTaskVo selectById(Long id);

    /**
     * 查询知识图谱任务列表
     *
     * @param kGraphTaskBo 知识图谱任务Bo
     * @return 知识图谱任务集合
     */
    List<KGraphTaskVo> selectList(KGraphTaskBo kGraphTaskBo);

    /**
     * 分页查询知识图谱任务列表
     *
     * @param kGraphTaskBo 知识图谱任务Bo
     * @return 分页知识图谱任务集合
     */
    PageResult<KGraphTaskVo> selectPage(KGraphTaskBo kGraphTaskBo);

    /**
     * 新增知识图谱任务
     *
     * @param kGraphTaskBo 知识图谱任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(KGraphTaskBo kGraphTaskBo);

    /**
     * 处理任务
     *
     * @param kGraphTaskBo 知识图谱任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean proTask(KGraphTaskBo kGraphTaskBo);

    /**
     * 新增知识图谱任务，前台提供主键值，一般用于导入的场合
     *
     * @param kGraphTaskBo 知识图谱任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(KGraphTaskBo kGraphTaskBo);

    /**
     * 修改知识图谱任务
     *
     * @param kGraphTaskBo 知识图谱任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(KGraphTaskBo kGraphTaskBo);

    /**
     * 批量删除知识图谱任务
     *
     * @param ids 需要删除的知识图谱任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    boolean resultCallback(ExtraKGraphTaskBo extraKGraphTaskBo);

    boolean statusCallback(ExtraKGraphTaskStatusBo extraKGraphTaskStatusBo);
}
