package org.eco.als.service;

import org.eco.als.domain.LifePrediction;
import org.eco.als.domain.bo.LifePredictionBo;
import org.eco.als.domain.vo.LifePredictionVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;

import java.util.List;

/**
 * 寿命预测Service接口
 *
 * @author wgk
 * @date 2024-07-26
 */
public interface ILifePredictionService extends IBaseService<LifePrediction> {
    /**
     * 查询寿命预测
     *
     * @param id 寿命预测主键
     * @return 寿命预测
     */
    LifePredictionVo selectById(Long id);

    /**
     * 查询寿命预测列表
     *
     * @param lifePredictionBo 寿命预测Bo
     * @return 寿命预测集合
     */
    List<LifePredictionVo> selectList(LifePredictionBo lifePredictionBo);

    /**
     * 分页查询寿命预测列表
     *
     * @param lifePredictionBo 寿命预测Bo
     * @return 分页寿命预测集合
     */
    PageResult<LifePredictionVo> selectPage(LifePredictionBo lifePredictionBo);

    /**
     * 新增寿命预测
     *
     * @param lifePredictionBo 寿命预测Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    LifePrediction insert(LifePredictionBo lifePredictionBo);

    /**
     * 新增寿命预测，前台提供主键值，一般用于导入的场合
     *
     * @param lifePredictionBo 寿命预测Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(LifePredictionBo lifePredictionBo);

    /**
     * 修改寿命预测
     *
     * @param lifePredictionBo 寿命预测Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(LifePredictionBo lifePredictionBo);

    /**
     * 批量删除寿命预测
     *
     * @param ids 需要删除的寿命预测主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<LifePredictionVo> listVo, String sheetName, LoginUser user);

}
