package org.eco.als.service;

import java.util.List;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.LifetimeSpareParts;
import org.eco.als.domain.vo.LifetimeSparePartsVo;
import org.eco.als.domain.bo.LifetimeSparePartsBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 有寿件Service接口
 *
 * @author wgk
 * @date 2024-12-14
 */
public interface ILifetimeSparePartsService extends IBaseService<LifetimeSpareParts> {
    /**
     * 查询有寿件
     *
     * @param id 有寿件主键
     * @return 有寿件
     */
        LifetimeSparePartsVo selectById(Long id);
    /**
     * 查询有寿件列表
     *
     * @param lifetimeSparePartsBo 有寿件Bo
     * @return 有寿件集合
     */
    List<LifetimeSparePartsVo> selectList(LifetimeSparePartsBo lifetimeSparePartsBo);

    /**
     * 分页查询有寿件列表
     *
     * @param lifetimeSparePartsBo 有寿件Bo
     * @return 分页有寿件集合
     */
    PageResult<LifetimeSparePartsVo> selectPage(LifetimeSparePartsBo lifetimeSparePartsBo);

    /**
     * 新增有寿件
     *
     * @param lifetimeSparePartsBo 有寿件Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(LifetimeSparePartsBo lifetimeSparePartsBo);

    /**
     * 新增有寿件，前台提供主键值，一般用于导入的场合
     *
     * @param lifetimeSparePartsBo 有寿件Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(LifetimeSparePartsBo lifetimeSparePartsBo);

    /**
     * 修改有寿件
     *
     * @param lifetimeSparePartsBo 有寿件Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(LifetimeSparePartsBo lifetimeSparePartsBo);

    /**
     * 批量删除有寿件
     *
     * @param ids 需要删除的有寿件主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<LifetimeSparePartsVo> listVo, String sheetName, LoginUser user);

}
