package org.eco.als.service;

import org.eco.als.domain.MaintenanceDecision;
import org.eco.als.domain.bo.MaintenanceDecisionBo;
import org.eco.als.domain.vo.MaintenanceDecisionVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;

import java.util.List;

/**
 * 辅助维修决策Service接口
 *
 * @author wgk
 * @date 2024-07-24
 */
public interface IMaintenanceDecisionService extends IBaseService<MaintenanceDecision> {
    /**
     * 查询辅助维修决策
     *
     * @param id 辅助维修决策主键
     * @return 辅助维修决策
     */
    MaintenanceDecisionVo selectById(Long id);

    /**
     * 查询辅助维修决策列表
     *
     * @param maintenanceDecisionBo 辅助维修决策Bo
     * @return 辅助维修决策集合
     */
    List<MaintenanceDecisionVo> selectList(MaintenanceDecisionBo maintenanceDecisionBo);

    /**
     * 分页查询辅助维修决策列表
     *
     * @param maintenanceDecisionBo 辅助维修决策Bo
     * @return 分页辅助维修决策集合
     */
    PageResult<MaintenanceDecisionVo> selectPage(MaintenanceDecisionBo maintenanceDecisionBo);

    /**
     * 新增辅助维修决策
     *
     * @param maintenanceDecisionBo 辅助维修决策Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(MaintenanceDecisionBo maintenanceDecisionBo);

    /**
     * 新增辅助维修决策，前台提供主键值，一般用于导入的场合
     *
     * @param maintenanceDecisionBo 辅助维修决策Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(MaintenanceDecisionBo maintenanceDecisionBo);

    /**
     * 修改辅助维修决策
     *
     * @param maintenanceDecisionBo 辅助维修决策Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(MaintenanceDecisionBo maintenanceDecisionBo);

    /**
     * 批量删除辅助维修决策
     *
     * @param ids 需要删除的辅助维修决策主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<MaintenanceDecisionVo> listVo, String sheetName, LoginUser user);

}
