package org.eco.als.service;

import org.eco.als.domain.MaintenanceRecord;
import org.eco.als.domain.bo.MaintenanceRecordBo;
import org.eco.als.domain.vo.MaintenanceRecordVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 维修记录Service接口
 *
 * @author wgk
 * @date 2024-07-19
 */
public interface IMaintenanceRecordService extends IBaseService<MaintenanceRecord> {
    /**
     * 查询维修记录
     *
     * @param id 维修记录主键
     * @return 维修记录
     */
    MaintenanceRecordVo selectById(Long id);

    /**
     * 查询维修记录列表
     *
     * @param maintenanceRecordBo 维修记录Bo
     * @return 维修记录集合
     */
    List<MaintenanceRecordVo> selectList(MaintenanceRecordBo maintenanceRecordBo);

    /**
     * 分页查询维修记录列表
     *
     * @param maintenanceRecordBo 维修记录Bo
     * @return 分页维修记录集合
     */
    PageResult<MaintenanceRecordVo> selectPage(MaintenanceRecordBo maintenanceRecordBo);

    /**
     * 新增维修记录
     *
     * @param maintenanceRecordBo 维修记录Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(MaintenanceRecordBo maintenanceRecordBo);

    /**
     * 新增维修记录，前台提供主键值，一般用于导入的场合
     *
     * @param maintenanceRecordBo 维修记录Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(MaintenanceRecordBo maintenanceRecordBo);

    /**
     * 修改维修记录
     *
     * @param maintenanceRecordBo 维修记录Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(MaintenanceRecordBo maintenanceRecordBo);

    /**
     * 批量删除维修记录
     *
     * @param ids 需要删除的维修记录主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<MaintenanceRecordVo> listVo, String sheetName, LoginUser user);

}
