package org.eco.als.service;

import java.util.List;

import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.Maintenance;
import org.eco.als.domain.vo.MaintenanceVo;
import org.eco.als.domain.bo.MaintenanceBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 维修信息Service接口
 *
 * @author wgk
 * @date 2024-10-25
 */
public interface IMaintenanceService extends IBaseService<Maintenance> {
    /**
     * 查询维修信息
     *
     * @param id 维修信息主键
     * @return 维修信息
     */
    MaintenanceVo selectById(Long id);

    /**
     * 查询维修信息列表
     *
     * @param maintenanceBo 维修信息Bo
     * @return 维修信息集合
     */
    List<MaintenanceVo> selectList(MaintenanceBo maintenanceBo);

    /**
     * 分页查询维修信息列表
     *
     * @param maintenanceBo 维修信息Bo
     * @return 分页维修信息集合
     */
    PageResult<MaintenanceVo> selectPage(MaintenanceBo maintenanceBo);

    /**
     * 新增维修信息
     *
     * @param maintenanceBo 维修信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(MaintenanceBo maintenanceBo);

    /**
     * 新增维修信息，前台提供主键值，一般用于导入的场合
     *
     * @param maintenanceBo 维修信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(MaintenanceBo maintenanceBo);

    /**
     * 修改维修信息
     *
     * @param maintenanceBo 维修信息Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(MaintenanceBo maintenanceBo);

    /**
     * 批量删除维修信息
     *
     * @param ids 需要删除的维修信息主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<MaintenanceVo> listVo, String sheetName, LoginUser user);

}
