package org.eco.als.service;

import org.eco.als.domain.Model;
import org.eco.als.domain.bo.ModelBo;
import org.eco.als.domain.vo.ModelVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 模型信息Service接口
 *
 * @author wgk
 * @date 2024-07-22
 */
public interface IModelService extends IBaseService<Model> {
    /**
     * 查询模型信息
     *
     * @param id 模型信息主键
     * @return 模型信息
     */
    ModelVo selectById(Long id);
    /**
     * 查询模型信息
     *
     * @param partId 部件
     * @return 模型信息
     */
    ModelVo selectByPartId(String partId);

    /**
     * 查询模型信息列表
     *
     * @param modelBo 模型信息Bo
     * @return 模型信息集合
     */
    List<ModelVo> selectList(ModelBo modelBo);

    /**
     * 分页查询模型信息列表
     *
     * @param modelBo 模型信息Bo
     * @return 分页模型信息集合
     */
    PageResult<ModelVo> selectPage(ModelBo modelBo);

    /**
     * 新增模型信息
     *
     * @param modelBo 模型信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(ModelBo modelBo);

    /**
     * 新增模型信息，前台提供主键值，一般用于导入的场合
     *
     * @param modelBo 模型信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(ModelBo modelBo);

    /**
     * 修改模型信息
     *
     * @param modelBo 模型信息Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(ModelBo modelBo);

    /**
     * 批量删除模型信息
     *
     * @param ids 需要删除的模型信息主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<ModelVo> listVo, String sheetName, LoginUser user);

}
