package org.eco.als.service;

import java.util.List;

import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.PartReplacement;
import org.eco.als.domain.vo.PartReplacementVo;
import org.eco.als.domain.bo.PartReplacementBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 换件记录Service接口
 *
 * @author wgk
 * @date 2024-10-25
 */
public interface IPartReplacementService extends IBaseService<PartReplacement> {
    /**
     * 查询换件记录
     *
     * @param id 换件记录主键
     * @return 换件记录
     */
    PartReplacementVo selectById(Long id);

    /**
     * 查询换件记录列表
     *
     * @param partReplacementBo 换件记录Bo
     * @return 换件记录集合
     */
    List<PartReplacementVo> selectList(PartReplacementBo partReplacementBo);

    /**
     * 分页查询换件记录列表
     *
     * @param partReplacementBo 换件记录Bo
     * @return 分页换件记录集合
     */
    PageResult<PartReplacementVo> selectPage(PartReplacementBo partReplacementBo);

    /**
     * 新增换件记录
     *
     * @param partReplacementBo 换件记录Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(PartReplacementBo partReplacementBo);

    /**
     * 新增换件记录，前台提供主键值，一般用于导入的场合
     *
     * @param partReplacementBo 换件记录Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(PartReplacementBo partReplacementBo);

    /**
     * 修改换件记录
     *
     * @param partReplacementBo 换件记录Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(PartReplacementBo partReplacementBo);

    /**
     * 批量删除换件记录
     *
     * @param ids 需要删除的换件记录主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<PartReplacementVo> listVo, String sheetName, LoginUser user);

}
