package org.eco.als.service;

import org.eco.als.domain.PreProcessing;
import org.eco.als.domain.bo.PreProcessingBo;
import org.eco.als.domain.vo.PreProcessingVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;

import java.util.List;

/**
 * 预处理Service接口
 *
 * @author wgk
 * @date 2024-07-22
 */
public interface IPreProcessingService extends IBaseService<PreProcessing> {
    /**
     * 查询预处理
     *
     * @param id 预处理主键
     * @return 预处理
     */
    PreProcessingVo selectById(Long id);

    /**
     * 查询预处理列表
     *
     * @param preProcessingBo 预处理Bo
     * @return 预处理集合
     */
    List<PreProcessingVo> selectList(PreProcessingBo preProcessingBo);

    /**
     * 分页查询预处理列表
     *
     * @param preProcessingBo 预处理Bo
     * @return 分页预处理集合
     */
    PageResult<PreProcessingVo> selectPage(PreProcessingBo preProcessingBo);

    /**
     * 新增预处理
     *
     * @param preProcessingBo 预处理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    PreProcessing insert(PreProcessingBo preProcessingBo);

    /**
     * 新增预处理，前台提供主键值，一般用于导入的场合
     *
     * @param preProcessingBo 预处理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(PreProcessingBo preProcessingBo);

    /**
     * 修改预处理
     *
     * @param preProcessingBo 预处理Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(PreProcessingBo preProcessingBo);

    /**
     * 批量删除预处理
     *
     * @param ids 需要删除的预处理主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<PreProcessingVo> listVo, String sheetName, LoginUser user);

}
