package org.eco.als.service;

import org.eco.als.domain.Product;
import org.eco.als.domain.bo.ProductBo;
import org.eco.als.domain.vo.ProductVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 产品树Service接口
 *
 * @author wgk
 * @date 2024-07-19
 */
public interface IProductService extends IBaseService<Product> {
    /**
     * 查询产品树
     *
     * @param id 产品树主键
     * @return 产品树
     */
    ProductVo selectById(Long id);

    /**
     * 查询产品树
     *
     * @param name 产品树
     * @return 产品树
     */
    ProductVo selectByName(String name);

    /**
     * 查询产品树列表
     *
     * @param productBo 产品树Bo
     * @return 产品树集合
     */
    List<ProductVo> selectList(ProductBo productBo);


    /**
     * 新增产品树
     *
     * @param productBo 产品树Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(ProductBo productBo);

    /**
     * 新增产品树，前台提供主键值，一般用于导入的场合
     *
     * @param productBo 产品树Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(ProductBo productBo);

    /**
     * 新增产品树，前台提供唯一名称，一般用于导入的场合
     *
     * @param productBo 产品树Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithName(ProductBo productBo);

    /**
     * 修改产品树
     *
     * @param productBo 产品树Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(ProductBo productBo);

    /**
     * 批量删除产品树
     *
     * @param ids 需要删除的产品树主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<ProductVo> listVo, String sheetName, LoginUser user);

}
