package org.eco.als.service;

import org.eco.als.domain.QaHistory;
import org.eco.als.domain.bo.QaHistoryBo;
import org.eco.als.domain.vo.QaHistoryVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 问答历史记录Service接口
 *
 * @author wgk
 * @date 2024-12-13
 */
public interface IQaHistoryService extends IBaseService<QaHistory> {
    /**
     * 查询问答历史记录
     *
     * @param id 问答历史记录主键
     * @return 问答历史记录
     */
    QaHistoryVo selectById(Long id);

    /**
     * 查询问答历史记录列表
     *
     * @param qaHistoryBo 问答历史记录Bo
     * @return 问答历史记录集合
     */
    List<QaHistoryVo> selectList(QaHistoryBo qaHistoryBo);
    /**
     * 查询问答历史记录统计
     *
     * @return 问答历史记录集合
     */
    List<QaHistoryVo> groupQuestion();

    /**
     * 分页查询问答历史记录列表
     *
     * @param qaHistoryBo 问答历史记录Bo
     * @return 分页问答历史记录集合
     */
    PageResult<QaHistoryVo> selectPage(QaHistoryBo qaHistoryBo);

    /**
     * 新增问答历史记录
     *
     * @param qaHistoryBo 问答历史记录Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(QaHistoryBo qaHistoryBo);

    /**
     * 新增问答历史记录，前台提供主键值，一般用于导入的场合
     *
     * @param qaHistoryBo 问答历史记录Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(QaHistoryBo qaHistoryBo);

    /**
     * 修改问答历史记录
     *
     * @param qaHistoryBo 问答历史记录Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(QaHistoryBo qaHistoryBo);

    /**
     * 批量删除问答历史记录
     *
     * @param ids 需要删除的问答历史记录主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<QaHistoryVo> listVo, String sheetName, LoginUser user);

}
