package org.eco.als.service;

import java.util.List;

import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.ResourceAllocation;
import org.eco.als.domain.vo.ResourceAllocationVo;
import org.eco.als.domain.bo.ResourceAllocationBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 维修任务资源分配Service接口
 *
 * @author wgk
 * @date 2024-11-14
 */
public interface IResourceAllocationService extends IBaseService<ResourceAllocation> {
    /**
     * 查询维修任务资源分配
     *
     * @param id 维修任务资源分配主键
     * @return 维修任务资源分配
     */
    ResourceAllocationVo selectById(Long id);

    /**
     * 查询维修任务资源分配列表
     *
     * @param resourceAllocationBo 维修任务资源分配Bo
     * @return 维修任务资源分配集合
     */
    List<ResourceAllocationVo> selectList(ResourceAllocationBo resourceAllocationBo);

    /**
     * 分页查询维修任务资源分配列表
     *
     * @param resourceAllocationBo 维修任务资源分配Bo
     * @return 分页维修任务资源分配集合
     */
    PageResult<ResourceAllocationVo> selectPage(ResourceAllocationBo resourceAllocationBo);

    /**
     * 新增维修任务资源分配
     *
     * @param resourceAllocationBo 维修任务资源分配Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(ResourceAllocationBo resourceAllocationBo);

    /**
     * 新增维修任务资源分配，前台提供主键值，一般用于导入的场合
     *
     * @param resourceAllocationBo 维修任务资源分配Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(ResourceAllocationBo resourceAllocationBo);

    /**
     * 修改维修任务资源分配
     *
     * @param resourceAllocationBo 维修任务资源分配Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(ResourceAllocationBo resourceAllocationBo);

    /**
     * 批量删除维修任务资源分配
     *
     * @param ids 需要删除的维修任务资源分配主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<ResourceAllocationVo> listVo, String sheetName, LoginUser user);

}
