package org.eco.als.service;

import org.eco.als.domain.Sortie;
import org.eco.als.domain.bo.SortieBo;
import org.eco.als.domain.vo.SortieVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 架次Service接口
 *
 * @author wgk
 * @date 2024-07-18
 */
public interface ISortieService extends IBaseService<Sortie> {
    /**
     * 查询架次
     *
     * @param id 架次主键
     * @return 架次
     */
    SortieVo selectById(Long id);

    /**
     * 查询架次列表
     *
     * @param sortieBo 架次Bo
     * @return 架次集合
     */
    List<SortieVo> selectList(SortieBo sortieBo);

    /**
     * 分页查询架次列表
     *
     * @param sortieBo 架次Bo
     * @return 分页架次集合
     */
    PageResult<SortieVo> selectPage(SortieBo sortieBo);

    /**
     * 新增架次
     *
     * @param sortieBo 架次Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(SortieBo sortieBo);

    /**
     * 新增架次，前台提供主键值，一般用于导入的场合
     *
     * @param sortieBo 架次Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(SortieBo sortieBo);

    /**
     * 修改架次
     *
     * @param sortieBo 架次Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(SortieBo sortieBo);

    /**
     * 批量删除架次
     *
     * @param ids 需要删除的架次主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<SortieVo> listVo, String sheetName, LoginUser user);

}
