package org.eco.als.service;

import org.eco.als.domain.SpareParts;
import org.eco.als.domain.bo.SparePartsBo;
import org.eco.als.domain.vo.SparePartsVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 部件Service接口
 *
 * @author wgk
 * @date 2024-07-25
 */
public interface ISparePartsService extends IBaseService<SpareParts> {
    /**
     * 查询部件
     *
     * @param id 部件主键
     * @return 部件
     */
    SparePartsVo selectById(Long id);

    /**
     * 查询部件列表
     *
     * @param sparePartsBo 部件Bo
     * @return 部件集合
     */
    List<SparePartsVo> selectList(SparePartsBo sparePartsBo);

    /**
     * 分页查询部件列表
     *
     * @param sparePartsBo 部件Bo
     * @return 分页部件集合
     */
    PageResult<SparePartsVo> selectPage(SparePartsBo sparePartsBo);

    /**
     * 新增部件
     *
     * @param sparePartsBo 部件Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(SparePartsBo sparePartsBo);

    /**
     * 新增部件，前台提供主键值，一般用于导入的场合
     *
     * @param sparePartsBo 部件Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(SparePartsBo sparePartsBo);

    /**
     * 修改部件
     *
     * @param sparePartsBo 部件Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(SparePartsBo sparePartsBo);

    /**
     * 批量删除部件
     *
     * @param ids 需要删除的部件主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<SparePartsVo> listVo, String sheetName, LoginUser user);

}
