package org.eco.als.service;

import org.eco.als.domain.Task;
import org.eco.als.domain.bo.TaskBo;
import org.eco.als.domain.vo.TaskVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 任务信息Service接口
 *
 * @author wgk
 * @date 2024-08-07
 */
public interface ITaskService extends IBaseService<Task> {
    /**
     * 查询任务信息
     *
     * @param id 任务信息主键
     * @return 任务信息
     */
    TaskVo selectById(Long id);

    /**
     * 查询任务信息列表
     *
     * @param taskBo 任务信息Bo
     * @return 任务信息集合
     */
    List<TaskVo> selectList(TaskBo taskBo);

    /**
     * 分页查询任务信息列表
     *
     * @param taskBo 任务信息Bo
     * @return 分页任务信息集合
     */
    PageResult<TaskVo> selectPage(TaskBo taskBo);

    /**
     * 新增任务信息
     *
     * @param taskBo 任务信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(TaskBo taskBo);

    /**
     * 新增任务信息，前台提供主键值，一般用于导入的场合
     *
     * @param taskBo 任务信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(TaskBo taskBo);

    /**
     * 修改任务信息
     *
     * @param taskBo 任务信息Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(TaskBo taskBo);

    /**
     * 批量删除任务信息
     *
     * @param ids 需要删除的任务信息主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<TaskVo> listVo, String sheetName, LoginUser user);

}
