package org.eco.als.service;

import org.eco.als.domain.WarningResult;
import org.eco.als.domain.bo.WarningResultBo;
import org.eco.als.domain.vo.WarningResultVo;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;

import java.util.List;

/**
 * 警告结果Service接口
 *
 * @author wgk
 * @date 2025-02-27
 */
public interface IWarningResultService extends IBaseService<WarningResult> {
    /**
     * 查询警告结果
     *
     * @param id 警告结果主键
     * @return 警告结果
     */
    WarningResultVo selectById(Long id);

    /**
     * 查询警告结果列表
     *
     * @param warningResultBo 警告结果Bo
     * @return 警告结果集合
     */
    List<WarningResultVo> selectList(WarningResultBo warningResultBo);

    /**
     * 分页查询警告结果列表
     *
     * @param warningResultBo 警告结果Bo
     * @return 分页警告结果集合
     */
    PageResult<WarningResultVo> selectPage(WarningResultBo warningResultBo);

    /**
     * 新增警告结果
     *
     * @param warningResultBo 警告结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(WarningResultBo warningResultBo);

    /**
     * 新增警告结果，前台提供主键值，一般用于导入的场合
     *
     * @param warningResultBo 警告结果Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(WarningResultBo warningResultBo);

    /**
     * 修改警告结果
     *
     * @param warningResultBo 警告结果Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(WarningResultBo warningResultBo);

    /**
     * 批量删除警告结果
     *
     * @param ids 需要删除的警告结果主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

}
