package org.eco.als.service;

import org.eco.als.domain.Warning;
import org.eco.als.domain.bo.WarningBo;
import org.eco.als.domain.vo.WarningVo;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;

import java.util.List;

/**
 * 警告信息Service接口
 *
 * @author wgk
 * @date 2024-07-22
 */
public interface IWarningService extends IBaseService<Warning> {
    /**
     * 查询警告信息
     *
     * @param id 警告信息主键
     * @return 警告信息
     */
    WarningVo selectById(Long id);

    /**
     * 查询警告信息列表
     *
     * @param warningBo 警告信息Bo
     * @return 警告信息集合
     */
    List<WarningVo> selectList(WarningBo warningBo);

    /**
     * 分页查询警告信息列表
     *
     * @param warningBo 警告信息Bo
     * @return 分页警告信息集合
     */
    PageResult<WarningVo> selectPage(WarningBo warningBo);

    /**
     * 新增警告信息
     *
     * @param warningBo 警告信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(WarningBo warningBo);

    /**
     * 新增警告信息，前台提供主键值，一般用于导入的场合
     *
     * @param warningBo 警告信息Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(WarningBo warningBo);

    /**
     * 修改警告信息
     *
     * @param warningBo 警告信息Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(WarningBo warningBo);

    /**
     * 批量删除警告信息
     *
     * @param ids 需要删除的警告信息主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

}
