package org.eco.als.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.mybatisflex.core.paginate.Page;
import com.mybatisflex.core.query.QueryWrapper;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.eco.als.domain.AirParamter;
import org.eco.als.domain.bo.AirParamterBo;
import org.eco.als.domain.vo.AirParamterVo;
import org.eco.als.mapper.AirParamterMapper;
import org.eco.als.service.IAirParamterService;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.core.utils.MapstructUtils;
import org.eco.common.orm.core.page.PageQuery;
import org.eco.common.orm.core.service.impl.BaseServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Arrays;
import java.util.List;

import static org.eco.als.domain.table.AirParamterTableDef.AIR_PARAMTER;

/**
 * 飞机系统参数管理Service业务层处理
 *
 * @author wgk
 * @date 2025-02-27
 */
@Service
@Slf4j
public class AirParamterServiceImpl extends BaseServiceImpl<AirParamterMapper, AirParamter> implements IAirParamterService {
    @Resource
    private AirParamterMapper airParamterMapper;

    @Override
    public QueryWrapper query() {
        return super.query().from(AIR_PARAMTER);
    }

    private QueryWrapper buildQueryWrapper(AirParamterBo airParamterBo) {
        QueryWrapper queryWrapper = super.buildBaseQueryWrapper();
        queryWrapper.and(AIR_PARAMTER.AIRCRAFT_TYPE.eq
            (airParamterBo.getAircraftType()));
        queryWrapper.and(AIR_PARAMTER.SYS_ID.eq
            (airParamterBo.getSysId()));
        queryWrapper.and(AIR_PARAMTER.SYS_NAME.like
            (airParamterBo.getSysName()));
        queryWrapper.and(AIR_PARAMTER.NAME.like
            (airParamterBo.getName()));
        queryWrapper.and(AIR_PARAMTER.NAME_ID.eq
            (airParamterBo.getNameId()));
        queryWrapper.and(AIR_PARAMTER.REMARKS.eq
            (airParamterBo.getRemarks()));
        queryWrapper.and(AIR_PARAMTER.ATTRIBUTE1.eq
            (airParamterBo.getAttribute1()));
        queryWrapper.and(AIR_PARAMTER.ATTRIBUTE2.eq
            (airParamterBo.getAttribute2()));
        queryWrapper.and(AIR_PARAMTER.ATTRIBUTE3.eq
            (airParamterBo.getAttribute3()));
        queryWrapper.and(AIR_PARAMTER.ATTRIBUTE4.eq
            (airParamterBo.getAttribute4()));
        queryWrapper.and(AIR_PARAMTER.ATTRIBUTE5.eq
            (airParamterBo.getAttribute5()));

        return queryWrapper;
    }

    /**
     * 查询飞机系统参数管理
     *
     * @param id 飞机系统参数管理主键
     * @return 飞机系统参数管理
     */
    @Override
    public AirParamterVo selectById(Long id) {
        return this.getOneAs(query().where(AIR_PARAMTER.ID.eq(id)), AirParamterVo.class);

    }


    /**
     * 查询飞机系统参数管理列表
     *
     * @param airParamterBo 飞机系统参数管理Bo
     * @return 飞机系统参数管理集合
     */
    @Override
    public List<AirParamterVo> selectList(AirParamterBo airParamterBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(airParamterBo);
        return this.listAs(queryWrapper, AirParamterVo.class);
    }

    /**
     * 分页查询飞机系统参数管理列表
     *
     * @param airParamterBo 飞机系统参数管理Bo
     * @return 分页飞机系统参数管理集合
     */
    @Override
    public PageResult<AirParamterVo> selectPage(AirParamterBo airParamterBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(airParamterBo);
        Page<AirParamterVo> page = this.pageAs(PageQuery.build(), queryWrapper, AirParamterVo.class);
        return PageResult.build(page);
    }

    /**
     * 新增飞机系统参数管理
     *
     * @param airParamterBo 飞机系统参数管理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    @Override
    public boolean insert(AirParamterBo airParamterBo) {
        AirParamter airParamter = MapstructUtils.convert(airParamterBo, AirParamter.class);

        return this.save(airParamter);//使用全局配置的雪花算法主键生成器生成ID值
    }

    /**
     * 新增飞机系统参数管理，前台提供主键值，一般用于导入的场合
     *
     * @param airParamterBo 飞机系统参数管理Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    @Override
    public boolean insertWithPk(AirParamterBo airParamterBo) {
        AirParamter airParamter = MapstructUtils.convert(airParamterBo, AirParamter.class);


        return airParamterMapper.insertWithPk(airParamter) > 0;//前台传来主键值
    }

    /**
     * 修改飞机系统参数管理
     *
     * @param airParamterBo 飞机系统参数管理Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    @Override
    public boolean update(AirParamterBo airParamterBo) {
        AirParamter airParamter = MapstructUtils.convert(airParamterBo, AirParamter.class);
        if (ObjectUtil.isNotNull(airParamter) && ObjectUtil.isNotNull(airParamter.getId())) {
            boolean updated = this.updateById(airParamter);
            return updated;
        }
        return false;
    }

    /**
     * 批量删除飞机系统参数管理
     *
     * @param ids 需要删除的飞机系统参数管理主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    @Transactional
    @Override
    public boolean deleteByIds(Long[] ids) {
        return this.removeByIds(Arrays.asList(ids));
    }

}
