package org.eco.system.service;

import org.eco.system.domain.SysOssConfig;
import org.eco.system.domain.bo.SysOssConfigBo;
import org.eco.system.domain.vo.SysOssConfigVo;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;

import java.util.Collection;

/**
 * 对象存储配置Service接口
 *
 * @author wgk
 * @date 2023-08-13
 */
public interface ISysOssConfigService extends IBaseService<SysOssConfig> {

    /**
     * 初始化OSS配置
     */
    void init();

    /**
     * 查询单个
     */
    SysOssConfigVo queryById(Long ossConfigId);

    /**
     * 查询列表
     */
    PageResult<SysOssConfigVo> queryPageList(SysOssConfigBo bo);


    /**
     * 根据新增业务对象插入对象存储配置
     *
     * @param bo 对象存储配置新增业务对象
     * @return
     */
    Boolean insertByBo(SysOssConfigBo bo);

    /**
     * 根据编辑业务对象修改对象存储配置
     *
     * @param bo 对象存储配置编辑业务对象
     * @return
     */
    Boolean updateByBo(SysOssConfigBo bo);

    /**
     * 校验并删除数据
     *
     * @param ids     主键集合
     * @param isValid 是否校验,true-删除前校验,false-不校验
     * @return
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);

    /**
     * 转到非默认状态
     */
    boolean updateOssConfigStatus(SysOssConfigBo bo);

}
